#!/usr/bin/python

#-------------------------------------------------------------------------------
#
#   Copyright (C) 2017 Cumulus Networks, Inc. All rights reserved
#
#   This software is subject to the Cumulus Networks End User License
#   Agreement available  at the following locations:
#
#   Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
#   Cumulus Linux systems: /usr/share/cumulus/EULA.txt
#
#-------------------------------------------------------------------------------

"""
This file contains constants for the BCM5389 and BCM5396 chips.
"""

#
#   Page 0x00
#
# portNCtrl - Base 0x00-0x0F
_PORT_CTRL_STP_STATE            = 0xE0
_PORT_CTRL_STP_STATE_NO_STP     = 0x00
_PORT_CTRL_STP_STATE_DISABLED   = 0x20
_PORT_CTRL_STP_STATE_BLOCKING   = 0x40
_PORT_CTRL_STP_STATE_LISTENING  = 0x60
_PORT_CTRL_STP_STATE_LEARNING   = 0x80
_PORT_CTRL_STP_STATE_FORWARDING = 0xA0
_PORT_CTRL_TX_DISABLE           = 0x02
_PORT_CTRL_RX_DISABLE           = 0x01

# switchMode96 - Base 0x20; and switchMode89 - Base 0x0B
_SWITCH_MODE_NOBLKCD            = 0x10
_SWITCH_MODE_FAST_TX_RET        = 0x08
_SWITCH_MODE_RTRY_LMT_DIS       = 0x04
_SWITCH_MODE_SW_FWDG_EN         = 0x02
_SWITCH_MODE_SW_FWDG_MODE       = 0x01

# resMcastCntrl96 - Base 0x50; and resMcastCntrl96 - Base 0x2f
_RES_MCAST_CNTRL_LEARN          = 0x80
_RES_MCAST_CNTRL_MUL4_DROP      = 0x10
_RES_MCAST_CNTRL_MUL3_DROP      = 0x08
_RES_MCAST_CNTRL_MUL2_DROP      = 0x04
_RES_MCAST_CNTRL_MUL1_DROP      = 0x02
_RES_MCAST_CNTRL_MUL0_DROP      = 0x01

# extPhyCtrl - Base 0x86
_EXT_PHY_CTRL_ENABLE            = 0x80
_EXT_PHY_CTRL_ADDR_INC          = 0x20
_EXT_PHY_CTRL_BASE_ADDR         = 0x1F

#
#   Page 0x04
#
# globalAlrCfg - Base 0x00
_GLOBAL_ARL_CFG_MPORT_ADDR_EN   = 0x10
_GLOBAL_ARL_CFG_HASH_DISABLE    = 0x01

#
#   Page 0x05
#
# vlanTblCntrl - Base 0x60
_VLAN_TBL_START                 = 0x80
_VLAN_TBL_READ                  = 0x01

#
#   Pages 0x10-0x1F
#
# portNSGMIICtrl - Base 0x20
_PORT_SGMII_CNTRL_GLOBAL_WR     = 0x2000
_PORT_SGMII_CNTRL_TX_AMP_OV     = 0x1000
_PORT_SGMII_CNTRL_CNTR_SEL      = 0x0800
_PORT_SGMII_CNTRL_REMOTE_LPBK   = 0x0400
_PORT_SGMII_CNTRL_CD_EN         = 0x0100
_PORT_SGMII_CNTRL_CRC_DIS       = 0x0080
_PORT_SGMII_CNTRL_RSVD          = 0x0040
_PORT_SGMII_CNTRL_SGMII_MSTR    = 0x0020
_PORT_SGMII_CNTRL_AUTODET_EN    = 0x0010
_PORT_SGMII_CNTRL_TBI           = 0x0002
_PORT_SGMII_CNTRL_FIBER         = 0x0001

#
#   Page 0x34
#
# dot1QGblCntrl - Base 0x00
_DOT1Q_GLB_CNTRL_EN             = 0x80
_DOT1Q_GLB_CNTRL_LEARN_IVL      = 0x60
_DOT1Q_GLB_CNTRL_LEARN_SVL      = 0x00
_DOT1Q_GLB_CNTRL_1Q_CHANGE_VID  = 0x08
_DOT1Q_GLB_CNTRL_1Q_CHANGE_PRIO = 0x04
_DOT1Q_GLB_CNTRL_1P_CHANGE_BOTH = 0x03
_DOT1Q_GLB_CNTRL_1P_CHANGE_VID  = 0x02

#
#   Pages 0x80-0x8F
#
# portNAutoNegAdv - Base 0x04
_PORT_AUTO_NEG_ADVER_NEXT_PAGE  = 0x8000
_PORT_AUTO_NEG_ADVER_ACK        = 0x4000
_PORT_AUTO_NEG_ADVER_RF         = 0x2000
_PORT_AUTO_NEG_ADVER_ASYN_PAUSE = 0x0800
_PORT_AUTO_NEG_ADVER_PAUSE      = 0x0400
_PORT_AUTO_NEG_ADVER_100BASET4  = 0x0200
_PORT_AUTO_NEG_ADVER_100FD      = 0x0100
_PORT_AUTO_NEG_ADVER_100HD      = 0x0080
_PORT_AUTO_NEG_ADVER_10FD       = 0x0040
_PORT_AUTO_NEG_ADVER_10HD       = 0x0020
_PORT_AUTO_NEG_ADVER_SEL_8023   = 0x0001

